import { useParams } from "react-router-dom";
import MyModal from "../../Components/MyModal";
import { Button, ConfigProvider, Flex, Result, Spin, notification } from "antd";
import { useEffect, useState } from "react";
import MyAppLogo from "../../Components/MyAppLogo";
import PageNotFound, { ButtonBackHome } from "../PageNotFound";
import { Constants, myFetch } from "../../utils";
import { useTranslation } from "react-i18next";
import { RequestState } from "../../Components/MyRequestStateItem";

export default function Verification() {
  const { state, emailVerificationId } = useParams();
  const { t } = useTranslation();
  const [notificationApi, notificationContextHolder] =
    notification.useNotification();

  const [isRequesting, setIsRequesting] = useState(RequestState.REQUESTING);

  const content = [
    {
      requesting: {
        title: t("verification.content.0.requesting.title"),
      },
      sucess: {
        title: t("verification.content.0.success.title"),
        extra: (
          <Button
            type="primary"
            onClick={() => {
              window.location.href = `${Constants.DASHBOARD_ADDRESS}${Constants.ROUTE_PATHS.AUTHENTICATION.LOGIN}`;
            }}
          >
            {t("verification.content.0.success.button")}
          </Button>
        ),
      },
    },
  ];

  const parsedState = isNaN(state) ? 0 : parseInt(state);

  let elementContent;

  if (
    state === undefined ||
    emailVerificationId === undefined ||
    state > content.length - 1
  ) {
    elementContent = <PageNotFound useHref />;
  } else if (isRequesting === RequestState.REQUESTING) {
    elementContent = (
      <Result
        title={content[parsedState].requesting.title}
        extra={<Spin size="large" />}
      />
    );
  } else if (isRequesting === RequestState.SUCCESS) {
    elementContent = (
      <Result
        status="success"
        title={content[parsedState].sucess.title}
        extra={content[parsedState].sucess.extra}
      />
    );
  } else if (isRequesting === RequestState.FAILED) {
    elementContent = (
      <Result
        status="error"
        title={t("verification.error.title")}
        subTitle={t("verification.error.description")}
        extra={<ButtonBackHome useHref />}
      />
    );
  } else {
    elementContent = <PageNotFound useHref />;
  }

  useEffect(() => {
    if (emailVerificationId === undefined || state === undefined) {
      setIsRequesting(false);
      return;
    }

    myFetch({
      url: `/user/verify/${state}/${emailVerificationId}`,
      notificationApi: notificationApi,
      t: t,
    })
      .then(() => setIsRequesting(RequestState.SUCCESS))
      .catch(() => setIsRequesting(RequestState.FAILED));
  }, []);

  return (
    <ConfigProvider
      theme={{
        token: {
          colorBgMask: "rgba(0, 0, 0, 0.0)",
        },
      }}
    >
      <MyModal isOpen={true} footer={null} closable={false}>
        {notificationContextHolder}

        <Flex justify="center">
          <MyAppLogo height={100} />
        </Flex>

        {elementContent}
      </MyModal>
    </ConfigProvider>
  );
}
